@@ -22,9 +22,9 @@ import qualified Git.Command
 import qualified Annex
 import Config.Files
 import Utility.FreeDesktop
+import Utility.DiskFree
 #ifdef WITH_CLIBS
 import Utility.Mounts
-import Utility.DiskFree
 #endif
 import Utility.DataUnits
 import Utility.Network
@@ -116,12 +116,18 @@ defaultRepositoryPath :: Bool -> IO FilePath
 defaultRepositoryPath firstrun = do
 	cwd <- liftIO getCurrentDirectory
 	home <- myHomeDir
+#ifndef mingw32_HOST_OS
 	if home == cwd && firstrun
 		then inhome
 		else ifM (legit cwd <&&> canWrite cwd)
 			( return cwd
 			, inhome
 			)
+#else
+	-- Windows user can probably write anywhere, so always default
+	-- to ~/Desktop/annex.
+	inhome
+#endif
   where
 	inhome = do
 		desktop <- userDesktopDir
@@ -207,7 +213,7 @@ getCombineRepositoryR newrepopath newrepouuid = do
 selectDriveForm :: [RemovableDrive] -> Hamlet.Html -> MkMForm RemovableDrive
 selectDriveForm drives = renderBootstrap $ RemovableDrive
 	<$> pure Nothing
-	<*> areq (selectFieldList pairs) "Select drive:" Nothing
+	<*> areq (selectFieldList pairs `withNote` onlywritable) "Select drive:" Nothing
 	<*> areq textField "Use this directory on the drive:"
 		(Just $ T.pack gitAnnexAssistantDefaultDir)
   where
@@ -221,6 +227,7 @@ selectDriveForm drives = renderBootstrap $ RemovableDrive
 				, T.concat ["(", T.pack sz]
 				, "free)"
 				]
+	onlywritable = [whamlet|This list only includes drives you can write to.|]
 
 removableDriveRepository :: RemovableDrive -> FilePath
 removableDriveRepository drive =
@@ -342,13 +349,14 @@ getEnableDirectoryR uuid = page "Enable a repository" (Just Configuration) $ do
 
 {- List of removable drives. -}
 driveList :: IO [RemovableDrive]
+#ifdef mingw32_HOST_OS
+-- Just enumerate all likely drive letters for Windows.
+-- Could use wmic, but it only works for administrators.
+driveList = mapM (\d -> genRemovableDrive $ d:":\\") ['A'..'Z']
+#else
 #ifdef WITH_CLIBS
-driveList = mapM (gen . mnt_dir) =<< filter sane <$> getMounts
+driveList = mapM (genRemovableDrive . mnt_dir) =<< filter sane <$> getMounts
   where
-	gen dir = RemovableDrive
-		<$> getDiskFree dir
-		<*> pure (T.pack dir)
-		<*> pure (T.pack gitAnnexAssistantDefaultDir)
 	-- filter out some things that are surely not removable drives
 	sane Mntent { mnt_dir = dir, mnt_fsname = dev }
 		{- We want real disks like /dev/foo, not
@@ -369,6 +377,13 @@ driveList = mapM (gen . mnt_dir) =<< filter sane <$> getMounts
 #else
 driveList = return []
 #endif
+#endif
+
+genRemovableDrive :: FilePath -> IO RemovableDrive
+genRemovableDrive dir = RemovableDrive
+	<$> getDiskFree dir
+	<*> pure (T.pack dir)
+	<*> pure (T.pack gitAnnexAssistantDefaultDir)
 
 {- Bootstraps from first run mode to a fully running assistant in a
  - repository, by running the postFirstRun callback, which returns the
