@@ -18,9 +18,14 @@ import Utility.LogFile
 import Utility.NotificationBroadcaster
 
 import Control.Concurrent
-import System.Posix (getProcessID, signalProcess, sigTERM)
 import qualified Data.Map as M
 import qualified Data.Text as T
+#ifndef mingw32_HOST_OS
+import System.Posix (getProcessID, signalProcess, sigTERM)
+#else
+import System.Win32.Process.Current (getCurrentProcessId)
+import System.Win32.Console (generateConsoleCtrlEvent, cTRL_C_EVENT)
+#endif
 
 getShutdownR :: Handler Html
 getShutdownR = page "Shutdown" Nothing $
@@ -48,7 +53,11 @@ getShutdownConfirmedR = do
 	 - page time to load in the browser. -}
 	void $ liftIO $ forkIO $ do
 		threadDelay 2000000
+#ifndef mingw32_HOST_OS
 		signalProcess sigTERM =<< getProcessID
+#else
+		generateConsoleCtrlEvent cTRL_C_EVENT =<< getCurrentProcessId
+#endif
 	redirect NotRunningR
 
 {- Use a custom page to avoid putting long polling elements on it that will 
